==> eiffelstudio-18.11.10.2592.tar: F_code/C6/sh266.c <==
/*
 * Code for class SHARED_ENCODING_CONVERTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sh266.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SHARED_ENCODING_CONVERTER}.encoding_converter */
EIF_REFERENCE F345_4713 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(4716,F345_4716,(Current))));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTLE;
		return (EIF_REFERENCE) loc1;
	} else {
		tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_4_2_0_0_0_0_0_0_);
		F1297_13527(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		F345_4715(Current, Result);
	}
	RTLE;
	return Result;
}

/* {SHARED_ENCODING_CONVERTER}.set_encoding_converter */
void F345_4715 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(4716,F345_4716,(Current));
	F136_1943(RTCW(tr1), arg1);
	RTLE;
}

/* {SHARED_ENCODING_CONVERTER}.encoding_converter_cell */
static EIF_REFERENCE F345_4716_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4716);
#define Result RTOSR(4716)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,135,1296,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 135, _OBJSIZ_1_0_0_0_0_0_0_0_);
	}
	F136_1943(RTCW(tr1), NULL);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4716);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F345_4716 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4716,F345_4716_body,(Current));
}

void EIF_Minit266 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/sh266.c <==
/*
 * Code for class SHARED_ENCODING_CONVERTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sh266.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SHARED_ENCODING_CONVERTER}.encoding_converter */
EIF_REFERENCE F345_4724 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(4727,F345_4727, (Current))));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTLE;
		return (EIF_REFERENCE) loc1;
	} else {
		Result = RTLNS(eif_new_type(1301, 0x01).id, 1301, _OBJSIZ_4_2_0_0_0_0_0_0_);
		F1302_13563(RTCW(Result));
		F345_4726(Current, Result);
	}
	RTLE;
	return Result;
}

/* {SHARED_ENCODING_CONVERTER}.set_encoding_converter */
void F345_4726 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(4727,F345_4727, (Current));
	F136_1952(RTCW(tr1), arg1);
	RTLE;
}

/* {SHARED_ENCODING_CONVERTER}.encoding_converter_cell */
static EIF_REFERENCE F345_4727_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4727);
#define Result RTOSR(4727)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,135,1301,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 135, _OBJSIZ_1_0_0_0_0_0_0_0_);
	}
	F136_1952(RTCW(tr1), NULL);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4727);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F345_4727 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4727,F345_4727_body,(Current));
}

void EIF_Minit266 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
